Stan Math Library: stan/math/prim/mat/meta/is_vector_like.hpp Source File

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- File List
- File Members

is_vector_like.hpp
Go to the documentation of this file.
1 #ifndef STAN_MATH_PRIM_MAT_META_IS_VECTOR_LIKE_HPP
2 #define STAN_MATH_PRIM_MAT_META_IS_VECTOR_LIKE_HPP
3
4 #include <stan/math/prim/scal/meta/is_vector_like.hpp>
5 #include <stan/math/prim/mat/fun/Eigen.hpp>
6
7 namespace stan {
8
21 template <typename T>
22 struct is_vector_like<Eigen::Matrix<T, Eigen::Dynamic, Eigen::Dynamic> > {
23 enum { value = true };
24 };
25 }
26 #endif
27
stan::is_vector_like
Template metaprogram indicates whether a type is vector_like.
Definition: is_vector_like.hpp:21
stan
Definition: log_sum_exp.hpp:8
Eigen
(Expert) Numerical traits for algorithmic differentiation variables.
Definition: Eigen_NumTraits.hpp:8
is_vector_like.hpp
stan::is_vector_like::value
Definition: is_vector_like.hpp:22
Eigen.hpp

[ Stan Home Page ] © 2011–2016, Stan Development Team.